<?php

namespace Drupal\o365_groups\Access;

use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;
use Drupal\group\Entity\Group;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Access check class for the files controller.
 */
class O365GroupsFilesControllerAccessCheck implements AccessInterface {

  /**
   * The current request.
   *
   * @var \Symfony\Component\HttpFoundation\Request|null
   */
  protected $request;

  /**
   * Constructor for the O365GroupsFilesControllerAccessCheck class.
   *
   * @param \Symfony\Component\HttpFoundation\RequestStack $requestStack
   *   The request stack.
   */
  public function __construct(RequestStack $requestStack) {
    $this->request = $requestStack->getCurrentRequest();
  }

  /**
   * Access check method.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The current user account.
   *
   * @return \Drupal\Core\Access\AccessResultAllowed|\Drupal\Core\Access\AccessResultForbidden
   *   Whether the user has access.
   */
  public function access(AccountInterface $account) {
    $group = $this->request->get('group');

    // Allowed to visit this page when there is a group and teams ID.
    if ($group) {
      if (is_string($group)) {
        $group = Group::load($group);
      }

      if ($group) {
        $teamsIdField = $group->get('field_o365_groups_teams_id')->getValue();
        if (!empty($teamsIdField)) {
          return AccessResult::allowed();
        }
      }
    }

    // Default is forbidden.
    return AccessResult::forbidden();
  }

}
